aboutsummaryrefslogtreecommitdiffstats
path: root/src/lib/ffmpeg-0.8
diff options
context:
space:
mode:
authork-m_schindler <k-m_schindler@b956fd51-792f-4845-bead-9b4dfca2ff2c>2012-07-13 17:05:41 +0000
committerk-m_schindler <k-m_schindler@b956fd51-792f-4845-bead-9b4dfca2ff2c>2012-07-13 17:05:41 +0000
commit9c836b13bb4277de91bee191e10e18e1c95953d8 (patch)
treee387d0b70e3de6f5bb9c16fcc86f51929b2b8209 /src/lib/ffmpeg-0.8
parent1118da7b66ae82d490b4ea06a7343798bf7ca120 (diff)
downloadusdx-9c836b13bb4277de91bee191e10e18e1c95953d8.tar.gz
usdx-9c836b13bb4277de91bee191e10e18e1c95953d8.tar.xz
usdx-9c836b13bb4277de91bee191e10e18e1c95953d8.zip
fixed revision numbers, macros, ...
git-svn-id: svn://svn.code.sf.net/p/ultrastardx/svn/trunk@2917 b956fd51-792f-4845-bead-9b4dfca2ff2c
Diffstat (limited to 'src/lib/ffmpeg-0.8')
-rw-r--r--src/lib/ffmpeg-0.8/avcodec.pas16
-rw-r--r--src/lib/ffmpeg-0.8/avformat.pas18
-rw-r--r--src/lib/ffmpeg-0.8/avio.pas26
-rw-r--r--src/lib/ffmpeg-0.8/avutil.pas13
-rw-r--r--src/lib/ffmpeg-0.8/libavutil/mem.pas2
-rw-r--r--src/lib/ffmpeg-0.8/libavutil/samplefmt.pas2
-rw-r--r--src/lib/ffmpeg-0.8/swscale.pas44
7 files changed, 71 insertions, 50 deletions
diff --git a/src/lib/ffmpeg-0.8/avcodec.pas b/src/lib/ffmpeg-0.8/avcodec.pas
index 56c6afb8..6a3d568f 100644
--- a/src/lib/ffmpeg-0.8/avcodec.pas
+++ b/src/lib/ffmpeg-0.8/avcodec.pas
@@ -22,7 +22,7 @@
* - Changes and updates by the UltraStar Deluxe Team
*
* Conversion of libavcodec/avcodec.h
- * version: 52.122.0
+ * version: 53.7.0 - 53.8.0
*
*)
@@ -79,16 +79,16 @@ const
* fix.
*)
(* Supported version by this header *)
- LIBAVCODEC_MAX_VERSION_MAJOR = 52;
- LIBAVCODEC_MAX_VERSION_MINOR = 122;
+ LIBAVCODEC_MAX_VERSION_MAJOR = 53;
+ LIBAVCODEC_MAX_VERSION_MINOR = 8;
LIBAVCODEC_MAX_VERSION_RELEASE = 0;
LIBAVCODEC_MAX_VERSION = (LIBAVCODEC_MAX_VERSION_MAJOR * VERSION_MAJOR) +
(LIBAVCODEC_MAX_VERSION_MINOR * VERSION_MINOR) +
(LIBAVCODEC_MAX_VERSION_RELEASE * VERSION_RELEASE);
(* Min. supported version by this header *)
- LIBAVCODEC_MIN_VERSION_MAJOR = 52;
- LIBAVCODEC_MIN_VERSION_MINOR = 122;
+ LIBAVCODEC_MIN_VERSION_MAJOR = 53;
+ LIBAVCODEC_MIN_VERSION_MINOR = 7;
LIBAVCODEC_MIN_VERSION_RELEASE = 0;
LIBAVCODEC_MIN_VERSION = (LIBAVCODEC_MIN_VERSION_MAJOR * VERSION_MAJOR) +
(LIBAVCODEC_MIN_VERSION_MINOR * VERSION_MINOR) +
@@ -96,12 +96,12 @@ const
(* Check if linked versions are supported *)
{$IF (LIBAVCODEC_VERSION < LIBAVCODEC_MIN_VERSION)}
-// {$MESSAGE Error 'Linked version of libavcodec is too old!'}
+ {$MESSAGE Error 'Linked version of libavcodec is too old!'}
{$IFEND}
(* Check if linked version is supported *)
{$IF (LIBAVCODEC_VERSION > LIBAVCODEC_MAX_VERSION)}
-// {$MESSAGE Error 'Linked version of libavcodec is not yet supported!'}
+ {$MESSAGE Error 'Linked version of libavcodec is not yet supported!'}
{$IFEND}
(**
@@ -175,7 +175,7 @@ const
{$IF FF_API_OLD_AUDIOCONVERT}
{$I libavcodec/audioconvert.pas}
-{$ENDIF}
+{$IFEND}
const
AV_NOPTS_VALUE: cint64 = $8000000000000000;
diff --git a/src/lib/ffmpeg-0.8/avio.pas b/src/lib/ffmpeg-0.8/avio.pas
index 99725ec3..a31d17e6 100644
--- a/src/lib/ffmpeg-0.8/avio.pas
+++ b/src/lib/ffmpeg-0.8/avio.pas
@@ -130,7 +130,7 @@ type
write_flag: cint; (**< true if open for writing *)
{$IF FF_API_OLD_AVIO}
is_streamed: cint; { deprecated }
-{$ENDIF}
+{$IFEND}
max_packet_size: cint;
checksum: culong;
checksum_ptr: PByteArray;
@@ -486,7 +486,7 @@ function url_close_buf(s: PAVIOContext): cint;
*)
function url_exist(url: {const} PAnsiChar): cint;
cdecl; external av__format; deprecated;
-{$ENDIF} // FF_API_OLD_AVIO
+{$IFEND} // FF_API_OLD_AVIO
(**
* Return AVIO_FLAG_* access flags corresponding to the access permissions
@@ -833,14 +833,30 @@ function url_is_streamed(s: PAVIOContext): cint;
begin
Result := s^.is_streamed;
end;
+{$IFEND}
+
+(**
+ * For SEEK_CUR on Windows
+ * values taken from stdio.h of C
+ *)
+{$IFNDEF SEEK_SET}
+const
+ SEEK_SET = 0;
+{$ENDIF}
+
+{$IFNDEF SEEK_CUR}
+const
+ SEEK_CUR = 1;
+{$ENDIF}
+
+{$IFNDEF SEEK_END}
+const
+ SEEK_END = 2;
{$ENDIF}
-{$IFDEF UNIX}
function avio_tell(s: PAVIOContext): cint64; {$IFDEF HasInline}inline;{$ENDIF}
begin
Result := avio_seek(s, 0, SEEK_CUR);
end;
-{$ELSE}
-{$ENDIF}
end.
diff --git a/src/lib/ffmpeg-0.8/avutil.pas b/src/lib/ffmpeg-0.8/avutil.pas
index 541aaa61..aca94cc0 100644
--- a/src/lib/ffmpeg-0.8/avutil.pas
+++ b/src/lib/ffmpeg-0.8/avutil.pas
@@ -98,8 +98,13 @@ const
(* libavutil/common.h *) // until now MKTAG and MKBETAG is all from common.h KMS 19/5/2010
-function MKTAG (a, b, c, d: AnsiChar): integer;
-function MKBETAG(a, b, c, d: AnsiChar): integer;
+(**
+ * MKTAG and MKBETAG are usually used to convert a magic string to an enumeration index.
+ * In Pascal this can probably not be used and the functions could be removed.
+ * KMS 8/6/2012
+ *)
+function MKTAG (a, b, c, d: AnsiChar): integer; {$IFDEF HasInline}inline;{$ENDIF}
+function MKBETAG(a, b, c, d: AnsiChar): integer; {$IFDEF HasInline}inline;{$ENDIF}
(**
* Return the LIBAVUTIL_VERSION_INT constant.
@@ -167,12 +172,12 @@ implementation
(* libavutil/common.h *)
-function MKTAG(a, b, c, d: AnsiChar): integer;
+function MKTAG(a, b, c, d: AnsiChar): integer; {$IFDEF HasInline}inline;{$ENDIF}
begin
Result := (ord(a) or (ord(b) shl 8) or (ord(c) shl 16) or (ord(d) shl 24));
end;
-function MKBETAG(a, b, c, d: AnsiChar): integer;
+function MKBETAG(a, b, c, d: AnsiChar): integer; {$IFDEF HasInline}inline;{$ENDIF}
begin
Result := (ord(d) or (ord(c) shl 8) or (ord(b) shl 16) or (ord(a) shl 24));
end;
diff --git a/src/lib/ffmpeg-0.8/libavutil/mem.pas b/src/lib/ffmpeg-0.8/libavutil/mem.pas
index c438bbfc..73bbf976 100644
--- a/src/lib/ffmpeg-0.8/libavutil/mem.pas
+++ b/src/lib/ffmpeg-0.8/libavutil/mem.pas
@@ -19,7 +19,7 @@
* - Changes and updates by the UltraStar Deluxe Team
*
* Conversion of libavutil/mem.h
- * avutil version 50.43.0
+ * avutil version 51.9.1
*
*)
diff --git a/src/lib/ffmpeg-0.8/libavutil/samplefmt.pas b/src/lib/ffmpeg-0.8/libavutil/samplefmt.pas
index 3335fa2d..c37a3740 100644
--- a/src/lib/ffmpeg-0.8/libavutil/samplefmt.pas
+++ b/src/lib/ffmpeg-0.8/libavutil/samplefmt.pas
@@ -19,7 +19,7 @@
* This is a part of the Pascal port of ffmpeg.
*
* Conversion of libavutil/samplefmt.h
- * avutil version 50.43.0
+ * avutil version 51.9.1
*
*)
diff --git a/src/lib/ffmpeg-0.8/swscale.pas b/src/lib/ffmpeg-0.8/swscale.pas
index f9f53d8c..b32cdeda 100644
--- a/src/lib/ffmpeg-0.8/swscale.pas
+++ b/src/lib/ffmpeg-0.8/swscale.pas
@@ -80,7 +80,7 @@ const
(* Check if linked versions are supported *)
{$IF (LIBSWSCALE_VERSION > LIBSWSCALE_MAX_VERSION)}
-// {$MESSAGE Error 'Linked version of libswscale is not yet supported!'}
+ {$MESSAGE Error 'Linked version of libswscale is not yet supported!'}
{$IFEND}
type
@@ -98,7 +98,7 @@ const
{$ifndef FF_API_SWS_CPU_CAPS}
FF_API_SWS_CPU_CAPS = LIBSWSCALE_VERSION_MAJOR < 3;
{$endif}
-{$ifndef FF_API_SWS_GETCONTEXT}
+{$ifndef FF_API_SWS_FORMAT_NAME}
FF_API_SWS_FORMAT_NAME = LIBSWSCALE_VERSION_MAJOR < 3;
{$endif}
@@ -150,7 +150,7 @@ const
SWS_ACCURATE_RND = $40000;
SWS_BITEXACT = $80000;
-{$if FF_API_SWS_CPU_CAPS}
+{$IF FF_API_SWS_CPU_CAPS}
(**
* CPU caps are autodetected now, those flags
* are only provided for API compatibility.
@@ -160,7 +160,7 @@ const
SWS_CPU_CAPS_3DNOW = $40000000;
SWS_CPU_CAPS_ALTIVEC = $10000000;
SWS_CPU_CAPS_BFIN = $01000000;
-{$endif}
+{$IFEND}
SWS_MAX_REDUCE_CUTOFF = 0.002;
@@ -244,7 +244,7 @@ function sws_init_context(sws_context: PSwsContext; srcFilter: PSwsFilter; dstFi
procedure sws_freeContext(swsContext: PSwsContext);
cdecl; external sw__scale;
-{$if FF_API_SWS_GETCONTEXT}
+{$IF FF_API_SWS_GETCONTEXT}
(**
* Allocates and returns a SwsContext. You need it to perform
* scaling/conversion operations using sws_scale().
@@ -260,10 +260,10 @@ procedure sws_freeContext(swsContext: PSwsContext);
*)
function sws_getContext(srcW: cint; srcH: cint; srcFormat: TAVPixelFormat;
dstW: cint; dstH: cint; dstFormat: TAVPixelFormat;
- flags: cint; srcFilter: PSwsFilter;
- dstFilter: PSwsFilter; param: PCdouble): PSwsContext;
+ flags: cint; srcFilter: PSwsFilter;
+ dstFilter: PSwsFilter; param: PCdouble): PSwsContext;
cdecl; external sw__scale;
-{$endif}
+{$IFEND}
(**
* Scales the image slice in srcSlice and puts the resulting scaled
@@ -301,7 +301,7 @@ function sws_scale(context: PSwsContext; {const} srcSlice: PPCuint8Array; {const
*)
function sws_scale_ordered(context: PSwsContext; {const} src: PPCuint8Array;
srcStride: PCintArray; srcSliceY: cint; srcSliceH: cint;
- dst: PPCuint8Array; dstStride: PCintArray): cint;
+ dst: PPCuint8Array; dstStride: PCintArray): cint;
cdecl; external sw__scale; deprecated;
{$ifend}
@@ -395,7 +395,7 @@ procedure sws_printVec(a: PSwsVector);
*)
procedure sws_printVec2(a: PSwsVector;
log_ctx: PAVClass; // PAVClass is declared in avcodec.pas
- log_level: cint);
+ log_level: cint);
cdecl; external sw__scale;
procedure sws_freeVec(a: PSwsVector);
@@ -403,8 +403,8 @@ procedure sws_freeVec(a: PSwsVector);
function sws_getDefaultFilter(lumaGBlur: cfloat; chromaGBlur: cfloat;
lumaSharpen: cfloat; chromaSharpen: cfloat;
- chromaHShift: cfloat; chromaVShift: cfloat;
- verbose: cint): PSwsFilter;
+ chromaHShift: cfloat; chromaVShift: cfloat;
+ verbose: cint): PSwsFilter;
cdecl; external sw__scale;
procedure sws_freeFilter(filter: PSwsFilter);
@@ -426,8 +426,8 @@ procedure sws_freeFilter(filter: PSwsFilter);
function sws_getCachedContext(context: PSwsContext;
srcW: cint; srcH: cint; srcFormat: TAVPixelFormat;
dstW: cint; dstH: cint; dstFormat: TAVPixelFormat;
- flags: cint; srcFilter: PSwsFilter;
- dstFilter: PSwsFilter; param: PCdouble): PSwsContext;
+ flags: cint; srcFilter: PSwsFilter;
+ dstFilter: PSwsFilter; param: PCdouble): PSwsContext;
cdecl; external sw__scale;
(**
@@ -440,10 +440,10 @@ function sws_getCachedContext(context: PSwsContext;
* @param num_pixels number of pixels to convert
* @param palette array with [256] entries, which must match color arrangement (RGB or BGR) of src
*)
-procedure sws_convertPalette8ToPacked32({const} src: PPCuint8Array;
- dst: PPCuint8Array;
- num_pixels: cint;
- {const} palette: PPCuint8Array);
+procedure sws_convertPalette8ToPacked32({const} src: PPCuint8Array;
+ dst: PPCuint8Array;
+ num_pixels: cint;
+ {const} palette: PPCuint8Array);
cdecl; external sw__scale;
(**
@@ -456,10 +456,10 @@ procedure sws_convertPalette8ToPacked32({const} src: PPCuint8Array;
* @param num_pixels number of pixels to convert
* @param palette array with [256] entries, which must match color arrangement (RGB or BGR) of src
*)
-procedure sws_convertPalette8ToPacked24({const} src: PPCuint8Array;
- dst: PPCuint8Array;
- num_pixels: cint;
- {const} palette: PPCuint8Array);
+procedure sws_convertPalette8ToPacked24({const} src: PPCuint8Array;
+ dst: PPCuint8Array;
+ num_pixels: cint;
+ {const} palette: PPCuint8Array);
cdecl; external sw__scale;
implementation
diff --git a/src/lib/ffmpeg-0.8/avformat.pas b/src/lib/ffmpeg-0.8/avformat.pas
index f119c784..bc87e551 100644
--- a/src/lib/ffmpeg-0.8/avformat.pas
+++ b/src/lib/ffmpeg-0.8/avformat.pas
@@ -21,9 +21,9 @@
* in the source codes.
* - Changes and updates by the UltraStar Deluxe Team
*
* Conversion of version 0.7 libavformat/avformat.h
* Min. version: 52.110.0
* Max. version: 52.111.0
*)
unit avformat;
@@ -61,16 +61,16 @@ const
* by removing all unneeded conditionals.
*)
(* Max. supported version by this header *)
- LIBAVFORMAT_MAX_VERSION_MAJOR = 52;
- LIBAVFORMAT_MAX_VERSION_MINOR = 111;
+ LIBAVFORMAT_MAX_VERSION_MAJOR = 53;
+ LIBAVFORMAT_MAX_VERSION_MINOR = 5;
LIBAVFORMAT_MAX_VERSION_RELEASE = 0;
LIBAVFORMAT_MAX_VERSION = (LIBAVFORMAT_MAX_VERSION_MAJOR * VERSION_MAJOR) +
(LIBAVFORMAT_MAX_VERSION_MINOR * VERSION_MINOR) +
(LIBAVFORMAT_MAX_VERSION_RELEASE * VERSION_RELEASE);
(* Min. supported version by this header *)
- LIBAVFORMAT_MIN_VERSION_MAJOR = 52;
- LIBAVFORMAT_MIN_VERSION_MINOR = 110;
+ LIBAVFORMAT_MIN_VERSION_MAJOR = 53;
+ LIBAVFORMAT_MIN_VERSION_MINOR = 4;
LIBAVFORMAT_MIN_VERSION_RELEASE = 0;
LIBAVFORMAT_MIN_VERSION = (LIBAVFORMAT_MIN_VERSION_MAJOR * VERSION_MAJOR) +
(LIBAVFORMAT_MIN_VERSION_MINOR * VERSION_MINOR) +
@@ -83,7 +83,7 @@ const
(* Check if linked versions are supported *)
{$IF (LIBAVFORMAT_VERSION > LIBAVFORMAT_MAX_VERSION)}
-// {$MESSAGE Error 'Linked version of libavformat is not yet supported!'}
+ {$MESSAGE Error 'Linked version of libavformat is not yet supported!'}
{$IFEND}
{
@@ -240,7 +240,7 @@ procedure av_metadata_copy(var dst: PAVDictionary; src: PAVDictionary; flags: ci
procedure av_metadata_free(var m: PAVDictionary);
cdecl; external av__format; deprecated;
-{$ENDIF}
+{$IFEND}
(* packet functions *)
@@ -21,9 +21,9 @@
* - Changes and updates by the UltraStar Deluxe Team
*
- * Conversion of version 0.7 libavformat/avformat.h
- * Min. version: 52.110.0
- * Max. version: 52.111.0
+ * Conversion of version 0.8 libavformat/avformat.h
+ * Min. version: 53.4.0
+ * Max. version: 53.5.0
*)
unit avformat;